<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dist?lang_cible=pt_br
// ** ne pas modifier le fichier **

return [

	// D
	'dist_description' => 'Conjunto de gabaritos distribuído com o SPIP 3.',
	'dist_slogan' => 'Gabaritos padrão do SPIP 3',
];
